==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/AnchorCircleExclamation.md <==
# AnchorCircleExclamation


```text
fontawesome-6/Solid/AnchorCircleExclamation
```

```text
include('fontawesome-6/Solid/AnchorCircleExclamation')
```



| Illustration | AnchorCircleExclamation |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/AnchorCircleExclamation.png) | ![illustration for AnchorCircleExclamation](../../fontawesome-6/Solid/AnchorCircleExclamation.Local.png) |




## AnchorCircleExclamation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element AnchorCircleExclamation
include('fontawesome-6/Solid/AnchorCircleExclamation')

' renders the element
AnchorCircleExclamation('AnchorCircleExclamation', 'Anchor Circle Exclamation', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element AnchorCircleExclamation
include('fontawesome-6/Solid/AnchorCircleExclamation')

' renders the element
AnchorCircleExclamation('AnchorCircleExclamation', 'Anchor Circle Exclamation', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/AnchorCircleExclamation.md <==
# AnchorCircleExclamation


```text
fontawesome-6/Solid/AnchorCircleExclamation
```

```text
include('fontawesome-6/Solid/AnchorCircleExclamation')
```



| Illustration | AnchorCircleExclamation |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/AnchorCircleExclamation.png) | ![illustration for AnchorCircleExclamation](../../fontawesome-6/Solid/AnchorCircleExclamation.Local.png) |




## AnchorCircleExclamation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element AnchorCircleExclamation
include('fontawesome-6/Solid/AnchorCircleExclamation')

' renders the element
AnchorCircleExclamation('AnchorCircleExclamation', 'Anchor Circle Exclamation', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element AnchorCircleExclamation
include('fontawesome-6/Solid/AnchorCircleExclamation')

' renders the element
AnchorCircleExclamation('AnchorCircleExclamation', 'Anchor Circle Exclamation', 'an optional tech label', 'an optional description')
@enduml
```
